@@ -1,21 +1,46 @@
 from libifstate.exception import LinkDuplicate
 from libifstate.link.base import Link
 from libifstate.address import Addresses
+from libifstate.routing import Tables, Rules
 from libifstate.parser import Parser
 from libifstate.util import logger, ipr, LogStyle
-from libifstate.exception import LinkNoConfigFound
+from libifstate.exception import LinkCircularLinked, LinkNoConfigFound, ParserValidationError
 from ipaddress import ip_network, ip_interface
+from jsonschema import validate, ValidationError
+import pkgutil
 import re
+import json
 
-__version__ = "0.5.1"
+__version__ = "0.6.1"
 
 class IfState():
     def __init__(self):
         self.links = {}
         self.addresses = {}
         self.ignore = {}
+        self.tables = None
+        self.rules = None
     
     def update(self, ifstates):
+        # check config schema
+        schema = json.loads(pkgutil.get_data("libifstate", "../schema/ifstate.conf.schema.json"))
+        try:
+            validate(ifstates, schema)
+        except ValidationError as ex:
+            if len(ex.path) > 0:
+                path = ["$"]
+                for i, p in enumerate(ex.path):
+                    if type(p) == int:
+                        path.append("[{}]".format(p))
+                    else:
+                        path.append(".")
+                        path.append(p)
+
+                detail = "{}: {}".format("".join(path),ex.message)
+            else:
+                detail = ex.message
+            raise ParserValidationError(detail)
+
         # add interfaces from config
         for ifstate in ifstates['interfaces']:
             name = ifstate['name']
@@ -31,6 +56,20 @@ class IfState():
             else:
                 self.addresses[name] = None
 
+        # add routing from config
+        if 'routing' in ifstates:
+            if 'routes' in ifstates['routing']:
+                if self.tables is None:
+                    self.tables = Tables()
+                for route in ifstates['routing']['routes']:
+                    self.tables.add(route)
+
+            if 'rules' in ifstates['routing']:
+                if self.rules is None:
+                    self.rules = Rules()
+                for rule in ifstates['routing']['rules']:
+                    self.rules.add(rule)
+
         # add ignore list items
         self.ignore.update(ifstates['ignore'])
 
@@ -96,6 +135,12 @@ class IfState():
         else:
             logger.info("\nno interface ip addressing to be applied")
 
+        if not self.tables is None:
+            self.tables.apply(self.ignore.get('routes', []))
+
+        if not self.rules is None:
+            self.rules.apply(self.ignore.get('rules', []))
+
     def show(self):
         self.ipaddr_ignore = set()
         for ip in Parser._default_ifstates.get('ignore').get('ipaddr'):
@@ -139,4 +184,8 @@ class IfState():
 
                 ifs_links.append(ifs_link)
 
-        return { **Parser._default_ifstates, **{'interfaces': ifs_links}}
+        routing = {
+            'routes': Tables().show_routes(Parser._default_ifstates['ignore']['routes']),
+        }
+
+        return { **Parser._default_ifstates, **{'interfaces': ifs_links, 'routing': routing}}
