@@ -12,3 +12,10 @@ class LinkCircularLinked(Exception):
 
 class LinkNoConfigFound(Exception):
     pass
+
+class ParserValidationError(Exception):
+    def __init__(self, detail):
+        self.detail = detail
+
+class RouteDupblicate(Exception):
+    pass
